Welcome to Django Stories’s documentation! — Django Stories v0.5.1 documentation

Django Stories v0.5.1 documentation

# Welcome to Django Stories’s documentation!

- Table of Contents
- index
  modules
  next

# Welcome to Django Stories’s documentation!

Contents:

- Installation
- Settings
  - STATUS_CHOICES
  - DEFAULT_STATUS
  - PUBLISHED_STATUS
  - ORIGIN_CHOICES
  - DEFAULT_ORIGIN
  - INCLUDE_PRINT
  - RELATION_MODELS
  - PAGINATION
  - THROW_404
  - AUTHOR_MODEL
  - AUTHOR_MODEL_LIMIT_CHOICES
  - USE_CATEGORIES
  - USE_REVERSION
- Pagination
  - PAGINATION settings
  - Using pagination in templates
- Integration with Other Django Applications
  - Integrating with Django Reversion
  - Integrating with Django TinyMCE
- User Manual
  - Entering a Story
  - Revisions
- Reference Manual
  - Models

# Indices and tables

- Index
- Module Index
- Search Page